.. _fs_average_template:

fsaverage template
==================

Access
------
See :func:`nilearn.datasets.fetch_surf_fsaverage`.

.. include:: fsaverage_content.rst

Notes
-----
Fsaverage standard surface as distributed with Freesurfer (:footcite:t:`Fischl1999`).

References
----------
.. footbibliography::

License
-------
unknown
